function y = grad(x, dir, dims)
% Y = GRAD(X, DIR, DIMS) gradient operator using circular boundary conditions:
%
%   y = [Dx; Dy; Dz; ... ] x
%
% Note: Using circular boundary conditions shouldn't be a problem, since
% there usually isn't anything interesting going on at the boundaries of an
% MRI image (due to limited spatial sensitivity). This isn't true for the
% temporal dimension, but  we prefer a circular boundary condition for cyclic
% motion such as in the heart
%
% Written by Christopher Sandino, 2017

    y = [];
    for i = 1:length(dims)
        % append gradient to last dimension
        y = cat(6, y, x-circshift(x, dir, dims(i)));
    end
end
