%% wrapping weights plot

v = linspace(-1.5, 1.5, 100);
y = 1 - logistic(abs(v), 0.75, 30);

figure; plot(v, y, 'LineWidth', 4);
    xlabel('Velocity (cm/s)'), ylabel('W_{wrap}');

%% arterial and venous plots

t = linspace(0,60,size(vel,3));
x1 = 14; % arterial
y1 = 22;
x2 = 15;
y2 = 44; % venous

figure; hold on;
plot(t, squeeze(abs(vel(y1,x1,:))), 'LineWidth', 4);
plot(t, squeeze(abs(vel(y2,x2,:))), 'LineWidth', 4);
title('Womersley velocity profiles');
xlabel('Time (s)'); ylabel('|Velocity| (cm/s)');
legend('Arterial (fast)', 'Venous (slow)');


%% phantom hdr for different lambda values

rho = 1;
lambda = [0.005, 0.01, 0.05];
velhdr1 = sum(wts.*vels, 6) ./ sum(wts, 6); % L-S

for l = 1:length(lambda)
    [velhdr2(:,:,:,:,1,l), res(:,1,l)] = hdrmrl1(vels, wts, ...
        lambda(l), rho, 'tv', [1 2 3]); % L-S + TV(space)
    [velhdr2(:,:,:,:,2,l), res(:,2,l)] = hdrmrl1(vels, wts, ...
        lambda(l), rho, 'tv', [4]); % L-S + TV(temp)
    [velhdr2(:,:,:,:,3,l), res(:,3,l)] = hdrmrl1(vels, wts, ...
        lambda(l), rho, 'tv', [1 2 3 4]); % L-S + TV(temp)
end

% plot images
veltruth = permute(repmat(vel, [1 1 1 nslices]),[1 2 4 3]);
% as(cat(2,veltruth, velhdr1, velhdr2));

% plot vels, mags, weight maps
slice = 32;
cph = 9;
lvl = 0.4;

figure; hold on;
for l = 1:size(velhdr2, 5)
    % truth
    subplot(3, 6, 6*(l-1)+1); imshow(veltruth(:,:,slice,cph), [-lvl, lvl]);
        title('Reference'); axis equal tight;
    % high venc acq
    subplot(3, 6, 6*(l-1)+2); imshow(vels(:,:,slice,cph,1,1), [-lvl, lvl]);
        title('High venc'); axis equal tight;
    % no reg
    subplot(3, 6, 6*(l-1)+3); imshow(velhdr1(:,:,slice,cph), [-lvl, lvl]);
        title('HDR'); axis equal tight;
    % tv(space),(time),(space+time)
    for i = 1:3
        subplot(3, 6, 6*(l-1)+3+i); imshow(velhdr2(:,:,slice,cph,l,i), [-lvl, lvl]);
            title(['HDR-TV(' num2str(lambda(i)) ')']); axis equal tight;
    end
end


% plot velocity profiles
t = linspace(0,60,size(vel,3));
x(1) = 14; % arterial
y(1) = 22;
x(2) = 15; % venous
y(2) = 44; 

figure; hold on;
for l = 1:size(velhdr2, 5)
    for v = 1:2 % loop over artery / vein
        % truth
        plot(t, squeeze(abs(veltruth(y(v),x(v),slice,:))), 'LineWidth', 4);
        % high venc acq
        plot(t, squeeze(abs(vels(y(v),x(v),slice,:,1,1))), 'LineWidth', 4);
    end
end
title('Womersley velocity profiles');
xlabel('Time (s)'); ylabel('|Velocity| (cm/s)');
legend('Arterial (fast)', 'Venous (slow)');

